@@ -29,18 +29,17 @@
 //
 ///////////////////////////////////////////////////////////////////////////
 
-/************************************************************************
-* Purpose: This file defines the Web Server and has functions to carry out 
-* operations of the Web Server.										
-************************************************************************/
+/******************************************************************************
+ * Purpose: This file defines the Web Server and has functions to carry out
+ * operations of the Web Server.
+ ******************************************************************************/
 
 #include "config.h"
 #include <assert.h>
 #include <fcntl.h>
 #ifndef UPNP_USE_BCBPP
-#ifndef UPNP_USE_MSVCPP
- #include <stdint.h>
-#endif
+    #include <inttypes.h>
+    #include <stdint.h>
 #endif
 #include "util.h"
 #include "strintmap.h"
@@ -54,7 +53,7 @@
 #include "ssdplib.h"
 
 #ifndef WIN32
- #include <unistd.h>
+    #include <unistd.h>
 #endif
 #include <sys/stat.h>
 #include "ithread.h"
@@ -63,8 +62,12 @@
 /*
    Response Types 
  */
-enum resp_type { RESP_FILEDOC, RESP_XMLDOC, RESP_HEADERS, RESP_WEBDOC,
-        RESP_POST };
+enum resp_type {
+	RESP_FILEDOC,
+	RESP_XMLDOC,
+	RESP_HEADERS,
+	RESP_WEBDOC,
+	RESP_POST };
 
 // mapping of file extension to content-type of document
 struct document_type_t {
@@ -94,18 +97,18 @@ static const char *gMediaTypes[] = {
  */
 
 // index into 'gMediaTypes'
-#define AUDIO_STR		"\1"
-#define VIDEO_STR		"\2"
-#define IMAGE_STR		"\3"
-#define APPLICATION_STR "\4"
-#define TEXT_STR		"\5"
+#define AUDIO_STR        "\1"
+#define VIDEO_STR        "\2"
+#define IMAGE_STR        "\3"
+#define APPLICATION_STR  "\4"
+#define TEXT_STR         "\5"
 
 // int index
-#define APPLICATION_INDEX	4
-#define TEXT_INDEX			5
+#define APPLICATION_INDEX 4
+#define TEXT_INDEX        5
 
 // general
-#define NUM_MEDIA_TYPES 69
+#define NUM_MEDIA_TYPES       69
 #define NUM_HTTP_HEADER_NAMES 33
 
 // sorted by file extension; must have 'NUM_MEDIA_TYPES' extensions
@@ -181,12 +184,9 @@ static const char *gEncodedMediaTypes =
     "zip\0" APPLICATION_STR "zip\0" "\0";
     // *** end ***
 
-/***********************************************************************/
-/*
+/************************************************************************
    module variables - Globals, static and externs                      
- */
-
-/***********************************************************************/
+************************************************************************/
 static struct document_type_t gMediaTypeList[NUM_MEDIA_TYPES];
 membuffer gDocumentRootDir;     // a local dir which serves as webserver root
 static struct xml_alias_t gAliasDoc;    // XML document
@@ -194,17 +194,17 @@ static ithread_mutex_t gWebMutex;
 extern str_int_entry Http_Header_Names[NUM_HTTP_HEADER_NAMES];
 
 /************************************************************************
-* Function: has_xml_content_type										
-*																		
-* Parameters:															
-*	none																
-*																		
-* Description: decodes list and stores it in gMediaTypeList				
-*																		
-* Returns:																
-*	 void																
-************************************************************************/
-static XINLINE void
+ * Function: has_xml_content_type
+ *
+ * Parameters:
+ *	none
+ *
+ * Description: decodes list and stores it in gMediaTypeList
+ *
+ * Returns:
+ *	 void
+ ************************************************************************/
+static UPNP_INLINE void
 media_list_init( void )
 {
     int i;
@@ -228,21 +228,21 @@ media_list_init( void )
 }
 
 /************************************************************************
-* Function: has_xml_content_type										
-*																		
-* Parameters:															
-*	IN const char* extension ; 											
-*	OUT const char** con_type,											
-*	OUT const char** con_subtype										
-*																		
-* Description: Based on the extension, returns the content type and 	
-*	content subtype														
-*																		
-* Returns:																
-*	 0 on success;														
-*	-1 on error															
-************************************************************************/
-static XINLINE int
+ * Function: has_xml_content_type
+ *
+ * Parameters:
+ *	IN const char* extension ;
+ *	OUT const char** con_type,
+ *	OUT const char** con_subtype
+ *
+ * Description: Based on the extension, returns the content type and
+ *	content subtype
+ *
+ * Returns:
+ *	 0 on success;
+ *	-1 on error
+ ************************************************************************/
+static UPNP_INLINE int
 search_extension( IN const char *extension,
                   OUT const char **con_type,
                   OUT const char **con_subtype )
@@ -275,21 +275,21 @@ search_extension( IN const char *extension,
 }
 
 /************************************************************************
-* Function: get_content_type											
-*																		
-* Parameters:															
-*	IN const char* filename,											
-*	OUT DOMString* content_type											
-*																		
-* Description: Based on the extension, clones an XML string based on	
-*	type and content subtype. If content type and sub type are not		
-*	found, unknown types are used										
-*																		
-* Returns:																
-*	 0 - On Sucess														
-*	 UPNP_E_OUTOF_MEMORY - on memory allocation failures				
-************************************************************************/
-XINLINE int
+ * Function: get_content_type
+ *
+ * Parameters:
+ *	IN const char* filename,
+ *	OUT DOMString* content_type
+ *
+ * Description: Based on the extension, clones an XML string based on
+ *	type and content subtype. If content type and sub type are not
+ *	found, unknown types are used
+ *
+ * Returns:
+ *	 0 - On Sucess
+ *	 UPNP_E_OUTOF_MEMORY - on memory allocation failures
+ ************************************************************************/
+UPNP_INLINE int
 get_content_type( IN const char *filename,
                   OUT DOMString * content_type )
 {
@@ -336,18 +336,18 @@ get_content_type( IN const char *filename,
 }
 
 /************************************************************************
-* Function: glob_alias_init												
-*																		
-* Parameters:															
-*	none																
-*																		
-* Description: Initialize the global XML document. Allocate buffers		
-*	for the XML document												
-*																		
-* Returns:																
-*	 void																
-************************************************************************/
-static XINLINE void
+ * Function: glob_alias_init
+ *
+ * Parameters:
+ *	none
+ *
+ * Description: Initialize the global XML document. Allocate buffers
+ *	for the XML document
+ *
+ * Returns:
+ *	 void
+ ************************************************************************/
+static UPNP_INLINE void
 glob_alias_init( void )
 {
     struct xml_alias_t *alias = &gAliasDoc;
@@ -359,34 +359,34 @@ glob_alias_init( void )
 }
 
 /************************************************************************
-* Function: is_valid_alias												
-*																		
-* Parameters:															
-*	IN const struct xml_alias_t* alias ; XML alias object				
-*																		
-* Description: Check for the validity of the XML object buffer													
-*																		
-* Returns:																
-*	 BOOLEAN															
-************************************************************************/
-static XINLINE xboolean
+ * Function: is_valid_alias
+ *
+ * Parameters:
+ *	IN const struct xml_alias_t* alias ; XML alias object
+ *
+ * Description: Check for the validity of the XML object buffer
+ *
+ * Returns:
+ *	 BOOLEAN
+ ************************************************************************/
+static UPNP_INLINE xboolean
 is_valid_alias( IN const struct xml_alias_t *alias )
 {
     return alias->doc.buf != NULL;
 }
 
 /************************************************************************
-* Function: alias_grab													
-*																		
-* Parameters:															
-*	OUT struct xml_alias_t* alias ; XML alias object										
-*																		
-* Description: Copy the contents of the global XML document into the	
-*	local OUT parameter																							
-*																		
-* Returns:																
-*	 void																
-************************************************************************/
+ * Function: alias_grab
+ *
+ * Parameters:
+ *	OUT struct xml_alias_t* alias ; XML alias object
+ *
+ * Description: Copy the contents of the global XML document into the
+ *	local OUT parameter
+ *
+ * Returns:
+ *	 void
+ ************************************************************************/
 static void
 alias_grab( OUT struct xml_alias_t *alias )
 {
@@ -401,17 +401,17 @@ alias_grab( OUT struct xml_alias_t *alias )
 }
 
 /************************************************************************
-* Function: alias_release												
-*																		
-* Parameters:															
-*	IN struct xml_alias_t* alias ; XML alias object										
-*																		
-* Description: Release the XML document referred to by the IN parameter 
-*	Free the allocated buffers associated with this object				
-*																		
-* Returns:																
-*	void																
-************************************************************************/
+ * Function: alias_release
+ *
+ * Parameters:
+ *	IN struct xml_alias_t* alias ; XML alias object
+ *
+ * Description: Release the XML document referred to by the IN parameter
+ *	Free the allocated buffers associated with this object
+ *
+ * Returns:
+ *	void
+ ************************************************************************/
 static void
 alias_release( IN struct xml_alias_t *alias )
 {
@@ -435,24 +435,24 @@ alias_release( IN struct xml_alias_t *alias )
 }
 
 /************************************************************************
-* Function: web_server_set_alias										
-*																		
-* Parameters:															
-*	alias_name: webserver name of alias; created by caller and freed by 
-*				caller (doesn't even have to be malloc()d .)					
-*	alias_content:	the xml doc; this is allocated by the caller; and	
-*					freed by the web server											
-*	alias_content_length: length of alias body in bytes					
-*	last_modified:	time when the contents of alias were last			
-*					changed (local time)											
-*																		
-* Description: Replaces current alias with the given alias. To remove	
-*	the current alias, set alias_name to NULL.							
-*																		
-* Returns:																
-*	0 - OK																
-*	UPNP_E_OUTOF_MEMORY: note: alias_content is not freed here			
-************************************************************************/
+ * Function: web_server_set_alias
+ *
+ * Parameters:
+ *	alias_name: webserver name of alias; created by caller and freed by
+ *		caller (doesn't even have to be malloc()d .)
+ *	alias_content:	the xml doc; this is allocated by the caller; and
+ *		freed by the web server
+ *	alias_content_length: length of alias body in bytes
+ *	last_modified:	time when the contents of alias were last
+ *		changed (local time)
+ *
+ * Description: Replaces current alias with the given alias. To remove
+ *	the current alias, set alias_name to NULL.
+ *
+ * Returns:
+ *	0 - OK
+ *	UPNP_E_OUTOF_MEMORY: note: alias_content is not freed here
+ ************************************************************************/
 int
 web_server_set_alias( IN const char *alias_name,
                       IN const char *alias_content,
@@ -515,28 +515,28 @@ web_server_set_alias( IN const char *alias_name,
 }
 
 /************************************************************************
-* Function: web_server_init												
-*																		
-* Parameters:															
-*	none																
-*																		
-* Description: Initilialize the different documents. Initialize the		
-*	memory for root directory for web server. Call to initialize global 
-*	XML document. Sets bWebServerState to WEB_SERVER_ENABLED			
-*																		
-* Returns:																
-*	0 - OK																
-*	UPNP_E_OUTOF_MEMORY: note: alias_content is not freed here			
-************************************************************************/
+ * Function: web_server_init
+ *
+ * Parameters:
+ *	none
+ *
+ * Description: Initilialize the different documents. Initialize the
+ *	memory for root directory for web server. Call to initialize global
+ *	XML document. Sets bWebServerState to WEB_SERVER_ENABLED
+ *
+ * Returns:
+ *	0 - OK
+ *	UPNP_E_OUTOF_MEMORY: note: alias_content is not freed here
+ ************************************************************************/
 int
 web_server_init( void )
 {
     int ret_code;
 
     if( bWebServerState == WEB_SERVER_DISABLED ) {
-        media_list_init(  );    // decode media list
+        media_list_init();    // decode media list
         membuffer_init( &gDocumentRootDir );
-        glob_alias_init(  );
+        glob_alias_init();
 
         pVirtualDirList = NULL;
 
@@ -551,18 +551,18 @@ web_server_init( void )
 }
 
 /************************************************************************
-* Function: web_server_destroy											
-*																		
-* Parameters:															
-*	none																
-*																		
-* Description: Release memory allocated for the global web server root	
-*	directory and the global XML document								
-*	Resets the flag bWebServerState to WEB_SERVER_DISABLED				
-*																		
-* Returns:																
-*	void																
-************************************************************************/
+ * Function: web_server_destroy
+ *
+ * Parameters:
+ *	none
+ *
+ * Description: Release memory allocated for the global web server root
+ *	directory and the global XML document
+ *	Resets the flag bWebServerState to WEB_SERVER_DISABLED
+ *
+ * Returns:
+ *	void
+ ************************************************************************/
 void
 web_server_destroy( void )
 {
@@ -583,23 +583,22 @@ web_server_destroy( void )
 }
 
 /************************************************************************
-* Function: get_file_info												
-*																		
-* Parameters:															
-*	IN const char* filename ; 	Filename having the description document
-*	OUT struct File_Info * info ; File information object having file 
-*								  attributes such as filelength, when was 
-*								  the file last modified, whether a file 
-*								  or a directory and whether the file or
-*								  directory is readable. 
-*																		
-* Description: Release memory allocated for the global web server root	
-*	directory and the global XML document								
-*	Resets the flag bWebServerState to WEB_SERVER_DISABLED				
-*																		
-* Returns:																
-*	int																	
-************************************************************************/
+ * Function: get_file_info
+ *
+ * Parameters:
+ *	IN const char* filename ;     Filename having the description document
+ *	OUT struct File_Info * info ; File information object having file 
+ *		attributes such as filelength, when was the file last
+ *		modified, whether a file or a directory and whether the
+ *		file or directory is readable.
+ *
+ * Description: Release memory allocated for the global web server root
+ *	directory and the global XML document
+ *	Resets the flag bWebServerState to WEB_SERVER_DISABLED
+ *
+ * Returns:
+ *	int
+ ************************************************************************/
 static int
 get_file_info( IN const char *filename,
                OUT struct File_Info *info )
@@ -636,29 +635,29 @@ get_file_info( IN const char *filename,
 
     rc = get_content_type( filename, &info->content_type );
 
-    DBGONLY( UpnpPrintf( UPNP_INFO, HTTP, __FILE__, __LINE__,
-                         "file info: %s, length: %lld, last_mod=%s readable=%d\n",
-                         filename, (long long)info->file_length,
-                         asctime( gmtime( &info->last_modified ) ),
-                         info->is_readable ); )
+    UpnpPrintf( UPNP_INFO, HTTP, __FILE__, __LINE__,
+        "file info: %s, length: %lld, last_mod=%s readable=%d\n",
+        filename, (long long)info->file_length,
+        asctime( gmtime( &info->last_modified ) ),
+        info->is_readable );
 
-        return rc;
+    return rc;
 }
 
 /************************************************************************
-* Function: web_server_set_root_dir										
-*																		
-* Parameters:															
-*	IN const char* root_dir ; String having the root directory for the 
-*								document		 						
-*																		
-* Description: Assign the path specfied by the IN const char* root_dir	
-*	parameter to the global Document root directory. Also check for		
-*	path names ending in '/'											
-*																		
-* Returns:																
-*	int																	
-************************************************************************/
+ * Function: web_server_set_root_dir
+ *
+ * Parameters:
+ *	IN const char* root_dir ; String having the root directory for the
+ *		document
+ *
+ * Description: Assign the path specfied by the IN const char* root_dir
+ *	parameter to the global Document root directory. Also check for
+ *	path names ending in '/'
+ *
+ * Returns:
+ *	int
+ ************************************************************************/
 int
 web_server_set_root_dir( IN const char *root_dir )
 {
@@ -681,25 +680,24 @@ web_server_set_root_dir( IN const char *root_dir )
 }
 
 /************************************************************************
-* Function: get_alias													
-*																		
-* Parameters:															
-*	IN const char* request_file ; request file passed in to be compared with
-*	OUT struct xml_alias_t* alias ; xml alias object which has a file name 
-*									stored										
-*   OUT struct File_Info * info	 ; File information object which will be 
-*									filled up if the file comparison 
-*									succeeds										
-*																		
-* Description: Compare the files names between the one on the XML alias 
-*	the one passed in as the input parameter. If equal extract file 
-*	information
-*																		
-* Returns:																
-*	TRUE - On Success													
-*	FALSE if request is not an alias									
-************************************************************************/
-static XINLINE xboolean
+ * Function: get_alias
+ *
+ * Parameters:
+ *	IN const char* request_file ; request file passed in to be compared with
+ *	OUT struct xml_alias_t* alias ; xml alias object which has a file name
+ *		stored
+ *   OUT struct File_Info * info	 ; File information object which will be
+ *		filled up if the file comparison succeeds
+ *
+ * Description: Compare the files names between the one on the XML alias
+ *	the one passed in as the input parameter. If equal extract file
+ *	information
+ *
+ * Returns:
+ *	TRUE - On Success
+ *	FALSE if request is not an alias
+ ************************************************************************/
+static UPNP_INLINE xboolean
 get_alias( IN const char *request_file,
            OUT struct xml_alias_t *alias,
            OUT struct File_Info *info )
@@ -719,17 +717,17 @@ get_alias( IN const char *request_file,
 }
 
 /************************************************************************
-* Function: isFileInVirtualDir											
-*																		
-* Parameters:															
-*	IN char *filePath ; directory path to be tested for virtual directory
-*																		
-* Description: Compares filePath with paths from the list of virtual
-*				directory lists
-*																		
-* Returns:																
-*	BOOLEAN																
-************************************************************************/
+ * Function: isFileInVirtualDir
+ *
+ * Parameters:
+ *	IN char *filePath ; directory path to be tested for virtual directory
+ *
+ * Description: Compares filePath with paths from the list of virtual
+ *	directory lists
+ *
+ * Returns:
+ *	BOOLEAN	
+ ************************************************************************/
 int
 isFileInVirtualDir( IN char *filePath )
 {
@@ -745,7 +743,7 @@ isFileInVirtualDir( IN char *filePath )
                 return TRUE;
         } else {
             if( ( strncmp( pCurVirtualDir->dirName, filePath, webDirLen )
-                  == 0 ) && ( filePath[webDirLen] == '/' ) )
+                  == 0 ) && ( filePath[webDirLen] == '/' || filePath[webDirLen] == '\0' || filePath[webDirLen] == '?' ) )
                 return TRUE;
         }
 
@@ -756,16 +754,16 @@ isFileInVirtualDir( IN char *filePath )
 }
 
 /************************************************************************
-* Function: ToUpperCase
-*
-* Parameters:
-*	INOUT char * Str ; Input string to be converted
-*
-* Description: Converts input string to upper case
-*
-* Returns:
-*	int
-************************************************************************/
+ * Function: ToUpperCase
+ *
+ * Parameters:
+ *	INOUT char * Str ; Input string to be converted
+ *
+ * Description: Converts input string to upper case
+ *
+ * Returns:
+ *	int
+ ************************************************************************/
 int
 ToUpperCase( char *Str )
 {
@@ -778,17 +776,17 @@ ToUpperCase( char *Str )
 }
 
 /************************************************************************
-* Function: StrStr
-*
-* Parameters:
-*	IN char * S1 ; Input string
-*	IN char * S2 ; Input sub-string
-*
-* Description: Finds a substring from a string
-*
-* Returns:
-*	char * ptr - pointer to the first occurence of S2 in S1				
-************************************************************************/
+ * Function: StrStr
+ *
+ * Parameters:
+ *	IN char * S1 ; Input string
+ *	IN char * S2 ; Input sub-string
+ *
+ * Description: Finds a substring from a string
+ *
+ * Returns:
+ *	char * ptr - pointer to the first occurence of S2 in S1
+ ************************************************************************/
 char *
 StrStr( char *S1,
         char *S2 )
@@ -828,17 +826,17 @@ StrStr( char *S1,
 }
 
 /************************************************************************
-* Function: StrTok														
-*																		
-* Parameters:															
-*	IN char ** Src ; String containing the token													
-*	IN char * del ; Set of delimiter characters														
-*																		
-* Description: Finds next token in a string							
-*																		
-* Returns:																
-*	char * ptr - pointer to the first occurence of S2 in S1				
-************************************************************************/
+ * Function: StrTok
+ *
+ * Parameters:
+ *	IN char ** Src ; String containing the token
+ *	IN char * del ; Set of delimiter characters
+ *
+ * Description: Finds next token in a string
+ *
+ * Returns:
+ *	char * ptr - pointer to the first occurence of S2 in S1
+ ************************************************************************/
 char *
 StrTok( char **Src,
         char *Del )
@@ -862,39 +860,41 @@ StrTok( char **Src,
 }
 
 /************************************************************************
-* Function: GetNextRange												
-*																		
-* Parameters:															
-*	IN char ** SrcRangeStr ; string containing the token / range										
-*	OUT int * FirstByte ;	 gets the first byte of the token												
-*	OUT int * LastByte	; gets the last byte of the token												
-*																		
-* Description: Returns a range of integers from a sring					
-*																		
-* Returns: int	;
-*	always returns 1;				
-************************************************************************/
+ * Function: GetNextRange
+ *
+ * Parameters:
+ *	IN char ** SrcRangeStr ; string containing the token / range
+ *	OUT int * FirstByte ;	 gets the first byte of the token
+ *	OUT int * LastByte	; gets the last byte of the token
+ *
+ * Description: Returns a range of integers from a string
+ *
+ * Returns: int	;
+ *	always returns 1;
+ ************************************************************************/
 int
 GetNextRange( char **SrcRangeStr,
               off_t *FirstByte,
               off_t *LastByte )
 {
-    char *Ptr,
-     *Tok;
-    int i,
-      F = -1,
-      L = -1;
+    char *Ptr;
+    char *Tok;
+    int i;
+    int64_t F = -1;
+    int64_t L = -1;
     int Is_Suffix_byte_Range = 1;
 
-    if( *SrcRangeStr == NULL )
+    if( *SrcRangeStr == NULL ) {
         return -1;
+    }
 
     Tok = StrTok( SrcRangeStr, "," );
 
-    if( ( Ptr = strstr( Tok, "-" ) ) == NULL )
+    if( ( Ptr = strstr( Tok, "-" ) ) == NULL ) {
         return -1;
+    }
     *Ptr = ' ';
-    sscanf( Tok, "%d%d", &F, &L );
+    sscanf( Tok, "%"SCNd64"%"SCNd64, &F, &L );
 
     if( F == -1 || L == -1 ) {
         *Ptr = '-';
@@ -909,36 +909,35 @@ GetNextRange( char **SrcRangeStr,
         }
 
         if( Is_Suffix_byte_Range ) {
-            *FirstByte = L;
-            *LastByte = F;
+            *FirstByte = (off_t)L;
+            *LastByte = (off_t)F;
             return 1;
         }
     }
+    *FirstByte = (off_t)F;
+    *LastByte = (off_t)L;
 
-    *FirstByte = F;
-    *LastByte = L;
     return 1;
-
 }
 
 /************************************************************************
-* Function: CreateHTTPRangeResponseHeader								
-*																		
-* Parameters:															
-*	char * ByteRangeSpecifier ; String containing the range 	
-*	long FileLength ; Length of the file													
-*	OUT struct SendInstruction * Instr ; SendInstruction object	where the 
-*										range operations will be stored
-*																		
-* Description: Fills in the Offset, read size and contents to send out	
-*	as an HTTP Range Response											
-*																		
-* Returns:																
-*	HTTP_BAD_REQUEST													
-*	UPNP_E_OUTOF_MEMORY													
-*	HTTP_REQUEST_RANGE_NOT_SATISFIABLE									
-*	HTTP_OK																
-************************************************************************/
+ * Function: CreateHTTPRangeResponseHeader
+ *
+ * Parameters:
+ *	char * ByteRangeSpecifier ; String containing the range
+ *	long FileLength ; Length of the file
+ *	OUT struct SendInstruction * Instr ; SendInstruction object
+ *		where the range operations will be stored
+ *
+ * Description: Fills in the Offset, read size and contents to send out
+ *	as an HTTP Range Response
+ *
+ * Returns:
+ *	HTTP_BAD_REQUEST
+ *	UPNP_E_OUTOF_MEMORY
+ *	HTTP_REQUEST_RANGE_NOT_SATISFIABLE
+ *	HTTP_OK	
+ ************************************************************************/
 int
 CreateHTTPRangeResponseHeader( char *ByteRangeSpecifier,
                                off_t FileLength,
@@ -990,7 +989,7 @@ CreateHTTPRangeResponseHeader( char *ByteRangeSpecifier,
             Instr->RangeOffset = FirstByte;
             Instr->ReadSendSize = LastByte - FirstByte + 1;
             sprintf( Instr->RangeHeader,
-                "CONTENT-RANGE: bytes %lld-%lld/%lld\r\n",
+                "CONTENT-RANGE: bytes %"PRId64"-%"PRId64"/%"PRId64"\r\n",
                 (int64_t)FirstByte,
                 (int64_t)LastByte,
                 (int64_t)FileLength );   //Data between two range.
@@ -999,7 +998,7 @@ CreateHTTPRangeResponseHeader( char *ByteRangeSpecifier,
             Instr->RangeOffset = FirstByte;
             Instr->ReadSendSize = FileLength - FirstByte;
             sprintf( Instr->RangeHeader,
-                     "CONTENT-RANGE: bytes %lld-%lld/%lld\r\n",
+                     "CONTENT-RANGE: bytes %"PRId64"-%"PRId64"/%"PRId64"\r\n",
                      (int64_t)FirstByte,
                      (int64_t)(FileLength - 1),
                      (int64_t)FileLength );
@@ -1008,14 +1007,14 @@ CreateHTTPRangeResponseHeader( char *ByteRangeSpecifier,
                 Instr->RangeOffset = 0;
                 Instr->ReadSendSize = FileLength;
                 sprintf( Instr->RangeHeader,
-                         "CONTENT-RANGE: bytes 0-%lld/%lld\r\n",
+                         "CONTENT-RANGE: bytes 0-%"PRId64"/%"PRId64"\r\n",
                          (int64_t)(FileLength - 1),
                          (int64_t)FileLength );
             } else {
                 Instr->RangeOffset = FileLength - LastByte;
                 Instr->ReadSendSize = LastByte;
                 sprintf( Instr->RangeHeader,
-                         "CONTENT-RANGE: bytes %lld-%lld/%lld\r\n",
+                         "CONTENT-RANGE: bytes %"PRId64"-%"PRId64"/%"PRId64"\r\n",
                          (int64_t)(FileLength - LastByte + 1),
                          (int64_t)FileLength,
                          (int64_t)FileLength );
@@ -1034,24 +1033,24 @@ CreateHTTPRangeResponseHeader( char *ByteRangeSpecifier,
 }
 
 /************************************************************************
-* Function: CheckOtherHTTPHeaders										
-*																		
-* Parameters:															
-*	IN http_message_t * Req ;  HTTP Request message
-*	OUT struct SendInstruction * RespInstr ; Send Instruction object to 
-*							data for the response
-*	int FileSize ;	Size of the file containing the request document
-*																		
-* Description: Get header id from the request parameter and take		
-*	appropriate action based on the ids.								
-*	as an HTTP Range Response											
-*																		
-* Returns:																
-*	HTTP_BAD_REQUEST													
-*	UPNP_E_OUTOF_MEMORY													
-*	HTTP_REQUEST_RANGE_NOT_SATISFIABLE									
-*	HTTP_OK																
-************************************************************************/
+ * Function: CheckOtherHTTPHeaders
+ *
+ * Parameters:
+ *	IN http_message_t * Req ;  HTTP Request message
+ *	OUT struct SendInstruction * RespInstr ; Send Instruction object to
+ *		data for the response
+ *	int FileSize ;	Size of the file containing the request document
+ *
+ * Description: Get header id from the request parameter and take
+ *	appropriate action based on the ids.
+ *	as an HTTP Range Response
+ *
+ * Returns:
+ *	HTTP_BAD_REQUEST
+ *	UPNP_E_OUTOF_MEMORY
+ *	HTTP_REQUEST_RANGE_NOT_SATISFIABLE
+ *	HTTP_OK
+ ************************************************************************/
 int
 CheckOtherHTTPHeaders( IN http_message_t * Req,
                        OUT struct SendInstruction *RespInstr,
@@ -1165,27 +1164,27 @@ CheckOtherHTTPHeaders( IN http_message_t * Req,
 }
 
 /************************************************************************
-* Function: process_request												
-*																		
-* Parameters:															
-*	IN http_message_t *req ; HTTP Request message												
-*	OUT enum resp_type *rtype ; Tpye of response											
-*	OUT membuffer *headers ; 												
-*	OUT membuffer *filename ; Get filename from request document
-*	OUT struct xml_alias_t *alias ; Xml alias document from the 
-*									request document,										
-*	OUT struct SendInstruction * RespInstr ; Send Instruction object 
-*					where the response is set up.										
-*																		
-* Description: Processes the request and returns the result in the OUT	
-*	parameters															
-*																		
-* Returns:																
-*	HTTP_BAD_REQUEST													
-*	UPNP_E_OUTOF_MEMORY													
-*	HTTP_REQUEST_RANGE_NOT_SATISFIABLE									
-*	HTTP_OK																
-************************************************************************/
+ * Function: process_request
+ *
+ * Parameters:
+ *	IN http_message_t *req ; HTTP Request message
+ *	OUT enum resp_type *rtype ; Tpye of response
+ *	OUT membuffer *headers ;
+ *	OUT membuffer *filename ; Get filename from request document
+ *	OUT struct xml_alias_t *alias ; Xml alias document from the
+ *		request document,
+ *	OUT struct SendInstruction * RespInstr ; Send Instruction object
+ *		where the response is set up.
+ *
+ * Description: Processes the request and returns the result in the OUT
+ *	parameters
+ *
+ * Returns:
+ *	HTTP_BAD_REQUEST
+ *	UPNP_E_OUTOF_MEMORY
+ *	HTTP_REQUEST_RANGE_NOT_SATISFIABLE
+ *	HTTP_OK
+ ************************************************************************/
 static int
 process_request( IN http_message_t * req,
                  OUT enum resp_type *rtype,
@@ -1206,7 +1205,7 @@ process_request( IN http_message_t * req,
     int resp_major,
       resp_minor;
     xboolean alias_grabbed;
-    int dummy;
+    size_t dummy;
     struct UpnpVirtualDirCallbacks *pVirtualDirCallback;
 
     print_http_headers( req );
@@ -1493,23 +1492,23 @@ process_request( IN http_message_t * req,
 }
 
 /************************************************************************
-* Function: http_RecvPostMessage										
-*																		
-* Parameters:															
-*	http_parser_t* parser ; HTTP Parser object							
-*	IN SOCKINFO *info ; Socket Information object													
-*	char * filename ; 	File where received data is copied to
-*	struct SendInstruction * Instr	; Send Instruction object which gives
-*			information whether the file is a virtual file or not.
-*																		
-* Description: Receives the HTTP post message														
-*																		
-* Returns:																
-*	HTTP_INTERNAL_SERVER_ERROR											
-*	HTTP_UNAUTHORIZED													
-*	HTTP_REQUEST_RANGE_NOT_SATISFIABLE									
-*	HTTP_OK																
-************************************************************************/
+ * Function: http_RecvPostMessage
+ *
+ * Parameters:
+ *	http_parser_t* parser ; HTTP Parser object
+ *	IN SOCKINFO *info ; Socket Information object
+ *	char * filename ; 	File where received data is copied to
+ *	struct SendInstruction * Instr	; Send Instruction object which gives
+ *		information whether the file is a virtual file or not.
+ *
+ * Description: Receives the HTTP post message
+ *
+ * Returns:
+ *	HTTP_INTERNAL_SERVER_ERROR
+ *	HTTP_UNAUTHORIZED
+ *	HTTP_REQUEST_RANGE_NOT_SATISFIABLE
+ *	HTTP_OK
+ ************************************************************************/
 int
 http_RecvPostMessage( http_parser_t * parser,
                       IN SOCKINFO * info,
@@ -1530,7 +1529,7 @@ http_RecvPostMessage( http_parser_t * parser,
 
     if( Instr && Instr->IsVirtualFile ) {
 
-        Fp = virtualDirCallback.open( filename, UPNP_WRITE );
+        Fp = (virtualDirCallback.open)( filename, UPNP_WRITE );
         if( Fp == NULL ) {
             return HTTP_INTERNAL_SERVER_ERROR;
         }
@@ -1585,14 +1584,11 @@ http_RecvPostMessage( http_parser_t * parser,
                 }
             } else if( num_read == 0 ) {
                 if( ok_on_close ) {
-                    DBGONLY( UpnpPrintf
-                             ( UPNP_INFO, HTTP, __FILE__, __LINE__,
-                               "<<< (RECVD) <<<\n%s\n-----------------\n",
-                               parser->msg.msg.buf );
-                             //print_http_headers( &parser->msg );
-                         )
-
-                        parser->position = POS_COMPLETE;
+                    UpnpPrintf( UPNP_INFO, HTTP, __FILE__, __LINE__,
+                        "<<< (RECVD) <<<\n%s\n-----------------\n",
+                        parser->msg.msg.buf );
+                    print_http_headers( &parser->msg );
+                    parser->position = POS_COMPLETE;
                 } else {
                     // partial msg
                     parser->http_error_code = HTTP_BAD_REQUEST; // or response
@@ -1660,19 +1656,19 @@ http_RecvPostMessage( http_parser_t * parser,
 }
 
 /************************************************************************
-* Function: web_server_callback											
-*																		
-* Parameters:															
-*	IN http_parser_t *parser ; HTTP Parser Object						
-*	INOUT http_message_t* req ; HTTP Message request										
-*	IN SOCKINFO *info ;			Socket information object													
-*																		
-* Description: main entry point into web server;						
-*	handles HTTP GET and HEAD requests									
-*																		
-* Returns:																
-*	void																
-************************************************************************/
+ * Function: web_server_callback
+ *
+ * Parameters:
+ *	IN http_parser_t *parser ; HTTP Parser Object
+ *	INOUT http_message_t* req ; HTTP Message request
+ *	IN SOCKINFO *info ;	Socket information object
+ *
+ * Description: main entry point into web server;
+ *	handles HTTP GET and HEAD requests
+ *
+ * Returns:
+ *	void
+ ************************************************************************/
 void
 web_server_callback( IN http_parser_t * parser,
                      INOUT http_message_t * req,
@@ -1759,10 +1755,10 @@ web_server_callback( IN http_parser_t * parser,
         }
     }
 
-    DBGONLY( UpnpPrintf( UPNP_INFO, HTTP, __FILE__, __LINE__,
-                         "webserver: request processed...\n" );
-         )
+    UpnpPrintf( UPNP_INFO, HTTP, __FILE__, __LINE__,
+        "webserver: request processed...\n" );
 
-        membuffer_destroy( &headers );
+    membuffer_destroy( &headers );
     membuffer_destroy( &filename );
 }
+
