@@ -244,7 +244,7 @@ get_node_value( IN IXML_Node * node )
 *
 *	Note :
 ****************************************************************************/
-static XINLINE int
+static UPNP_INLINE int
 get_host_and_path( IN char *ctrl_url,
                    OUT const memptr *host,
                    OUT const memptr *path,
@@ -277,7 +277,7 @@ get_host_and_path( IN char *ctrl_url,
 *
 *	Note :
 ****************************************************************************/
-static XINLINE int
+static UPNP_INLINE int
 get_action_name( IN char *action,
                  OUT memptr * name )
 {
@@ -303,7 +303,7 @@ get_action_name( IN char *action,
 *
 *	Note :
 ****************************************************************************/
-static XINLINE int
+static UPNP_INLINE int
 add_man_header( INOUT membuffer * headers )
 {
     char *soap_action_hdr;
@@ -611,19 +611,18 @@ SoapSendAction( IN char *action_url,
     char *xml_end =
         "</s:Body>\r\n"
         "</s:Envelope>\r\n\r\n";
-    int xml_start_len;
-    int xml_end_len;
-    int action_str_len;
+    size_t xml_start_len;
+    size_t xml_end_len;
+    size_t action_str_len;
 
     *response_node = NULL;      // init
 
     err_code = UPNP_E_OUTOF_MEMORY; // default error
 
-    DBGONLY( UpnpPrintf( UPNP_INFO, SOAP, __FILE__, __LINE__,
-                         "Inside SoapSendAction():" );
-         )
-        // init
-        membuffer_init( &request );
+    UpnpPrintf( UPNP_INFO, SOAP, __FILE__, __LINE__,
+        "Inside SoapSendAction():" );
+    // init
+    membuffer_init( &request );
     membuffer_init( &responsename );
 
     // print action
@@ -642,11 +641,12 @@ SoapSendAction( IN char *action_url,
         goto error_handler;
     }
 
-    DBGONLY( UpnpPrintf( UPNP_INFO, SOAP, __FILE__, __LINE__,
-                         "path=%.*s, hostport=%.*s\n",
-                         url.pathquery.size, url.pathquery.buff,
-                         url.hostport.text.size,
-                         url.hostport.text.buff ); )
+    UpnpPrintf( UPNP_INFO, SOAP, __FILE__, __LINE__,
+        "path=%.*s, hostport=%.*s\n",
+        (int)url.pathquery.size,
+        url.pathquery.buff,
+        (int)url.hostport.text.size,
+        url.hostport.text.buff );
 
     xml_start_len = strlen( xml_start );
     xml_end_len = strlen( xml_end );
@@ -693,7 +693,7 @@ SoapSendAction( IN char *action_url,
         err_code = ret_code;
     }
 
-  error_handler:
+error_handler:
     ixmlFreeDOMString( action_str );
     membuffer_destroy( &request );
     membuffer_destroy( &responsename );
@@ -757,24 +757,23 @@ SoapSendActionEx( IN char *action_url,
     char *xml_end =
         "</s:Body>\r\n"
         "</s:Envelope>\r\n";
-    int xml_start_len;
-    int xml_header_start_len;
-    int xml_header_str_len;
-    int xml_header_end_len;
-    int xml_body_start_len;
-    int action_str_len;
-    int xml_end_len;
+    size_t xml_start_len;
+    size_t xml_header_start_len;
+    size_t xml_header_str_len;
+    size_t xml_header_end_len;
+    size_t xml_body_start_len;
+    size_t action_str_len;
+    size_t xml_end_len;
     off_t content_length;
 
     *response_node = NULL;      // init
 
     err_code = UPNP_E_OUTOF_MEMORY; // default error
 
-    DBGONLY( UpnpPrintf( UPNP_INFO, SOAP, __FILE__, __LINE__,
-                         "Inside SoapSendActionEx():" );
-         )
-        // init
-        membuffer_init( &request );
+    UpnpPrintf( UPNP_INFO, SOAP, __FILE__, __LINE__,
+        "Inside SoapSendActionEx():" );
+    // init
+    membuffer_init( &request );
     membuffer_init( &responsename );
 
     // header string
@@ -798,11 +797,12 @@ SoapSendActionEx( IN char *action_url,
         goto error_handler;
     }
 
-    DBGONLY( UpnpPrintf( UPNP_INFO, SOAP, __FILE__, __LINE__,
-                         "path=%.*s, hostport=%.*s\n",
-                         url.pathquery.size, url.pathquery.buff,
-                         url.hostport.text.size,
-                         url.hostport.text.buff ); )
+    UpnpPrintf( UPNP_INFO, SOAP, __FILE__, __LINE__,
+        "path=%.*s, hostport=%.*s\n",
+        (int)url.pathquery.size,
+        url.pathquery.buff,
+        (int)url.hostport.text.size,
+        url.hostport.text.buff );
 
     xml_start_len = strlen( xml_start );
     xml_body_start_len = strlen( xml_body_start );
@@ -821,7 +821,7 @@ SoapSendActionEx( IN char *action_url,
         xml_body_start_len + action_str_len + xml_end_len;
     if (http_MakeMessage(
         &request, 1, 1,
-        "q" "N" "s" "sssbsc" "Uc" "bbbbbbb",
+        "q" "N" "s" "sssbsc" "Uc" "b" "b" "b" "b" "b" "b" "b",
         SOAPMETHOD_POST, &url,
         content_length,
         ContentTypeHeader,
